@@ -3,7 +3,7 @@ import os
 
 # target folder where all of the samples live
 root = os.path.dirname(os.path.dirname(__file__))
-target_folder = os.path.join(root, 'honeybee_schema', 'samples')
+target_folder = os.path.join(root, 'samples', 'simulation_parameter')
 
 
 def test_detailed_simulation_par():
